/** Class to define a data type for picture frame objects.
 */
public class Frame {
    
   /** Class value used to generate frame IDs. */
   private static int counter = 1; 

   /** The width of a frame, in inches. */
   private double width; 
   /** The height of a frame, in inches. */
   private double height; 
   /** The frame mode, 'S' for single, 'D' for dual. */
   private char mode;
   /** The frame id number. */
   private int id; 
 
 
   /** Create a frame object.
   @param w the width, in inches 
   @param h the height, in inches 
   @param m the mode of the frame 
   */ 
   public Frame(double w, double h, char m) { 
      this.width = w; 
      this.height = h; 
      m = Character.toUpperCase(m); 
      if (m == 'D') {
         this.mode = m;
      }
      else {
         this.mode = 'S';
      }
      this.id = counter; 
      counter++; 
   } 
 
   /** Create a frame object.
   @param s contains the width, height, and mode in this format 
      width height mode 
   */ 
   public Frame(String s) {
      int space = s.indexOf(' ');
      this.width = Double.parseDouble(s.substring(0, space));
      s = s.substring(space + 1);
      space = s.indexOf(' ');
      this.height = Double.parseDouble(s.substring(0, space)); 
      this.mode = s.charAt(space + 1);  
      this.id = counter; 
      counter++; 
   } 
 
   /** Make a string containing all the frame data.
   @return the string 
   */ 
   public String toString() { 
      return "ID: " + this.id + " [" + this.width + "," 
         + this.height + "] " + this.mode; 
   } 
 
   /** Determine if the frame is in dual mode.
   @return true if so, false otherwise 
   */ 
   public boolean isDual() { 
      return this.mode == 'D'; 
   }    
 
   /** Returns ID of the frame.
   @return ID of the frame 
   */ 
   public int getID() { 
      return this.id; 
   } 
    
   /** Returns width of the frame.
   @return width of the frame 
   */ 
   public double getWidth() { 
      return this.width; 
   } 
    
   /** Returns height of the frame.
   @return height of the frame 
   */ 
   public double getHeight() { 
      return this.height; 
   } 
}
