/** Class to store a collection of picture frames.
*/
public class FrameCollection {

   private static final int DEFAULT_SIZE = 10;
   
   private int num;
   private Frame[] frames;

/** Create a frameCollection object.
*/
   public FrameCollection() {
      this.frames = new Frame[DEFAULT_SIZE];
      this.num = 0;
   }

/** Add a frame object to the collection.
    @param f frame to be added to the collection
*/
   public void addFrame(Frame f) {
      if (this.num == this.frames.length) {
         this.resize();
      }
   		
      this.frames[this.num++] = f;
   }

/** Double the size of the collection.
*/
   private void resize() {
      Frame[] temp = new Frame[2 * this.frames.length];
      for (int i = 0; i < this.frames.length; i++) {
         temp[i] = this.frames[i];
      }
      this.frames = temp;
   }

/** Find a frame given its ID.
    @param id the ID of the frame to find
    @return the frame if found, null if not
*/
   public Frame findFrame(int id) {
      for (int i = 0; i < this.num; i++) {
         if (this.frames[i].getID() == id) {
            return this.frames[i];
         }
      }
      return null;
   }

/** Print the collection of frames.
*/
   public void printFrames() {
      for (int i = 0; i < this.num; i++) {
         if (this.frames[i] != null) {
            System.out.println(this.frames[i]);
         }
      }
   }
}
