import java.util.Scanner; 
import java.io.FileReader;
import java.io.IOException;
 
/**  
 * Main program for Picture Frame lab.
 * 
 * This file is not checkstyle compliant and you don't have to fix it.
 */ 
public class PicFrames { 
   private static Scanner keyboard = new Scanner(System.in); 
    
   public static void main(String[] args) throws IOException { 
      PictureCollection picColl = new PictureCollection(); 
      FrameCollection frameColl = new FrameCollection(); 
   
      Picture pic1;    // temporary picture
      Frame frame1;    // temporary frame
   
      String filename, line; 
   
      System.out.println("Welcome to the Picture Framing Program!"); 
      System.out.print("Please enter the name of the picture file: "); 
      filename = keyboard.nextLine(); 
       
      // read input from pictures file 
      Scanner input = new Scanner(new FileReader(filename));
      while (input.hasNextLine()) { 
         line = input.nextLine(); 
         Picture temp = new Picture(line); 
         picColl.addPicture(temp); 
      }  
       
      System.out.println(); 
      System.out.print("Please enter the name of the frame file: "); 
      filename = keyboard.nextLine(); 
       
      // read input from frames file 
      input = new Scanner(new FileReader(filename));
      while (input.hasNextLine()) { 
         line = input.nextLine(); 
         Frame temp2 = new Frame(line); 
         frameColl.addFrame(temp2); 
      }        
       
      System.out.println(); 
      System.out.print("Please enter the name of the transactions file: "); 
      filename = keyboard.nextLine(); 
       
      // read input from transactions file 
      input = new Scanner(new FileReader(filename));
      while (input.hasNextLine()) {  
         char trans = input.next().charAt(0); 
         switch (trans)  { 
            case 'F':
               frameColl.printFrames();
               input.nextLine();
               break; 
            case 'P':
               picColl.printPictures(); 
               input.nextLine();
               break; 
            case 'A':
               frameColl.addFrame(new Frame(input.nextLine().trim())); 
               break; 
            case 'D':
               picColl.removePicture(input.nextLine().trim()); 
               break; 
            case 'M':
               pic1 = picColl.findPicture(input.nextInt()); 
               frame1 = frameColl.findFrame(input.nextInt()); 
               match(pic1, frame1);
               input.nextLine();
               break; 
            case 'R':
               frame1 = frameColl.findFrame(input.nextInt()); 
               pic1 = picColl.findLargestPicture(); 
               if (frame1 == null) {
                  System.out.println("Error: Frame ID is invalid");
               }
               else {
                  resolution(frame1, pic1);
               }
               input.nextLine();
               break; 
            default:
               System.out.println("Error: Invalid Transaction Code");
               input.nextLine();
         } 
      }  
       
   }    


   public static void match(Picture pic1, Frame frame1) {
      if (pic1 == null)  { 
         System.out.println("Error: Picture ID is invalid");    
      } 
      else if (frame1 == null) { 
         System.out.println("Error: Frame ID is invalid");    
      }           
      else if (frame1.getWidth() * Picture.getResolution() >= pic1.getWidth() 
              && frame1.getHeight() * Picture.getResolution() >= pic1.getHeight()) {
         System.out.println("Yes, picture " + pic1.getID()
                           + " fits in frame " + frame1.getID()); 
      }
      else if (frame1.isDual() 
              && frame1.getHeight() * Picture.getResolution() >= pic1.getWidth() 
              && frame1.getWidth() * Picture.getResolution() >= pic1.getHeight()) {
         System.out.println("Yes, picture " + pic1.getID()
                           + " fits in frame " + frame1.getID());
      }
      else {
         System.out.println("No, picture " + pic1.getID()
                           + " does not fit in frame " + frame1.getID());
      }
   }

   public static void resolution(Frame frame2, Picture pic2) {
      double width1 = Math.ceil(pic2.getWidth() / frame2.getHeight()); 
      double height1 = Math.ceil(pic2.getHeight() / frame2.getWidth()); 
      double width2 = Math.ceil(pic2.getWidth() / frame2.getWidth()); 
      double height2 = Math.ceil(pic2.getHeight() / frame2.getHeight()); 
                       
      double newRes; 
                       
      if (frame2.isDual())   {
         newRes = Math.min(Math.max(width1, height1), Math.max(width2, height2)); 
      }
      else  {
         newRes = Math.max(width2, height2); 
      }
              
      System.out.println("New resolution is: " + (int) newRes + " pixels per inch"); 
      Picture.setResolution((int) newRes);  
   }

} 


/*  HERE IS THE EXPECTED OUTPUT OF THIS PROGRAM

using pictures.txt, frames.txt, transactions.txt as input

ID: 1 [10.0,10.0] D
ID: 2 [8.0,5.0] S
ID: 3 [4.0,4.0] S
ID: 4 [3.0,4.0] S
ID: 5 [5.0,4.0] D
ID: 6 [3.0,3.0] S
ID: 7 [6.0,6.0] D
ID: 8 [6.0,5.0] S
ID: 9 [6.0,4.0] D
ID: 10 [6.0,4.0] S
 PID: 3 carrots [100,200]  perim:9.375
 PID: 5 shades [300,100]  perim:12.5
 PID: 7 dixie cup on bed [430,120]  perim:17.1875
 PID: 2 blue sky [350,250]  perim:18.75
 PID: 4 cranberry juice [400,200]  perim:18.75
 PID: 1 red dog [300,400]  perim:21.875
 PID: 6 johnny [500,400]  perim:28.125
 PID: 8 puzzles [500,400]  perim:28.125
ID: 1 [10.0,10.0] D
ID: 2 [8.0,5.0] S
ID: 3 [4.0,4.0] S
ID: 4 [3.0,4.0] S
ID: 5 [5.0,4.0] D
ID: 6 [3.0,3.0] S
ID: 7 [6.0,6.0] D
ID: 8 [6.0,5.0] S
ID: 9 [6.0,4.0] D
ID: 10 [6.0,4.0] S
ID: 11 [3.0,4.0] S
 PID: 3 carrots [100,200]  perim:9.375
 PID: 5 shades [300,100]  perim:12.5
 PID: 7 dixie cup on bed [430,120]  perim:17.1875
 PID: 2 blue sky [350,250]  perim:18.75
 PID: 4 cranberry juice [400,200]  perim:18.75
 PID: 6 johnny [500,400]  perim:28.125
 PID: 8 puzzles [500,400]  perim:28.125
 No, picture 4 does not fit in frame 5
 Yes, picture 3 fits in frame 1
 Yes, picture 4 fits in frame 2

*/
